Module beamlit.models.request_duration_over_time_metrics
========================================================

Classes
-------

`RequestDurationOverTimeMetrics(request_duration_over_time: beamlit.types.Unset | ForwardRef('RequestDurationOverTimeMetric') = <beamlit.types.Unset object>)`
:   Request duration over time metrics
    
    Attributes:
        request_duration_over_time (Union[Unset, RequestDurationOverTimeMetric]): Request duration over time metric
    
    Method generated by attrs for class RequestDurationOverTimeMetrics.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `request_duration_over_time`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :